# This file is MACHINE GENERATED! Do not edit.
# Generated by: tensorflow/tools/api/generator/create_python_api.py script.
"""Generic entry point script.
"""

from __future__ import print_function

from tensorflow.python.platform.app import run

del print_function
